@@ -14,7 +14,7 @@ use Carp qw(croak carp);
 #######################
 # VERSION
 #######################
-our $VERSION = '0.071';
+our $VERSION = '0.08';
 
 #######################
 # SETTINGS
@@ -293,7 +293,9 @@ sub _run {
 
     # Build argument string
     my $arg_str = q();
-    if (@args) { $arg_str = join( ' ', '-arg', @args ); }
+    if (@args) {
+        $arg_str = join( ' ', map { "-arg=$_" } @args );
+    }
 
     # Get option string for $cmd
     my $opt_str = $self->_get_option_str( $cmd, $context );
@@ -350,70 +352,69 @@ sub _get_cmd_options {
 
     my $options = {
         'common'    => [qw(o v oa wts)],
-        'hft'       => [qw(a b fo fs)],
-        'hauthsync' => [qw(b eh pw usr)],
-        'husrunlk'  => [qw(b eh pw usr)],
-        'hsigset'   => [qw(purge context)],
-        'hdelss'    => [qw(b eh en pw usr)],
-        'hgetusg'   => [qw(b cu pu pw usr)],
-        'hpkgunlk'  => [qw(b eh en pw usr)],
-        'hsigget'   => [qw(a t v gl purge)],
-        'hppolget'  => [qw(b f eh gl pw usr)],
-        'hppolset'  => [qw(b f eh fc pw usr)],
-        'hsmtp'     => [qw(d f m p s cc bcc)],
-        'himpenv'   => [qw(b f eh pw iug usr)],
-        'hchu'      => [qw(b eh pw npw usr ousr)],
-        'hdbgctrl'  => [qw(b eh pw rm usr rport)],
-        'hcp'       => [qw(b at eh en pn pw st usr)],
-        'hformsync' => [qw(b d f eh pw all hfd usr)],
-        'hdlp'      => [qw(b eh en pn pw st usr pkgs)],
-        'hdv'       => [qw(b s eh en pn pw st vp usr)],
         'haccess'   => [qw(b eh en ft ha pw rn ug usr)],
         'hap'       => [qw(b c eh en pn pw st rej usr)],
-        'hdp'       => [qw(b eh en pb pd pn pw st usr)],
-        'hsql'      => [qw(b f s t eh eh gl nh pw usr)],
-        'hudp'      => [qw(b ap eh en ip pn pw st usr)],
-        'hchgtype'  => [qw(b q eh pw rp bin ext txt usr)],
-        'hcrrlte'   => [qw(b d eh en pw usr epid epname)],
-        'hexpenv'   => [qw(b f eh en pw cug eac eug usr)],
-        'hspp'      => [qw(b s eh en fp pn pw st tp usr)],
-        'hpp'       => [qw(b eh en pb pd pm pn pw st usr)],
-        'hmvpkg'    => [qw(b eh en ph pn pw st ten tst usr)],
         'har'       => [qw(b f m eh er pw mpw usr musr rport)],
-        'hrt'       => [qw(b f m eh er pw mpw usr musr rport)],
+        'hauthsync' => [qw(b eh pw usr)],
+        'hcbl'      => [qw(b eh en pw rp rw ss st add rdp rmr usr)],
         'hccmrg'    => [qw(b p eh en ma mc pn pw st tb tt usr)],
+        'hchgtype'  => [qw(b q eh pw rp bin ext txt usr)],
+        'hchu'      => [qw(b eh pw npw usr ousr)],
+        'hci'       => [qw(b d p s bo cp de eh en er if nd ob op ot pn pw rm ro st tr uk ur vp dcp dvp rpw usr rusr rport)],
+        'hcmpview'  => [qw(b s eh pw en1 en2 st1 usr uv1 uv2 vn1 vn2 vp1 vp2 cidc ciic)],
+        'hco'       => [qw(b p r s bo br cp cu eh en er nt op pf pn po pw rm ro ss st sy tb to tr up vn vp ced dcp dvp nvf nvs rpw usr rusr rport replace)],
+        'hcp'       => [qw(b at eh en pn pw st usr)],
+        'hcpj'      => [qw(b eh pw act cpj cug dac ina npj tem usr)],
+        'hcropmrg'  => [qw(b eh mo p1 p2 pn pw en1 en2 plo st1 st2 usr vfs)],
+        'hcrrlte'   => [qw(b d eh en pw usr epid epname)],
+        'hcrtpath'  => [qw(b p de eh en ob ot pw rp st usr cipn)],
+        'hdbgctrl'  => [qw(b eh pw rm usr rport)],
+        'hdelss'    => [qw(b eh en pw usr)],
+        'hdlp'      => [qw(b eh en pn pw st usr pkgs)],
+        'hdp'       => [qw(b eh en pb pd pn pw st adp pdr usr vdr)],
+        'hdv'       => [qw(b s eh en pn pw st vp usr)],
+        'hexecp'    => [qw(b m er ma pw prg syn usr args asyn rport)],
+        'hexpenv'   => [qw(b f eh en pw cug eac eug usr)],
+        'hfatt'     => [qw(b at cp eh er fn ft pw rm add fid get rem rpw usr comp rusr rport)],
+        'hformsync' => [qw(b d f eh pw all hfd usr)],
+        'hft'       => [qw(a b fo fs)],
+        'hgetusg'   => [qw(b cu pu pw usr)],
+        'himpenv'   => [qw(b f eh pw iug usr)],
+        'hlr'       => [qw(b c f cp eh er pw rm rp rpw usr rcep rusr rport)],
+        'hlv'       => [qw(b s ac cd eh en pn pw ss st vn vp usr)],
+        'hmvitm'    => [qw(b p de eh en np ob ot pn pw st uk ur vp usr)],
+        'hmvpkg'    => [qw(b eh en ph pn pw st ten tst usr)],
+        'hmvpth'    => [qw(b p de eh en np ob ot pn pw st uk ur vp usr)],
+        'hpg'       => [qw(b bp eh en pg pw st app cpg dpg dpp usr)],
+        'hpkgunlk'  => [qw(b eh en pw usr)],
+        'hpp'       => [qw(b eh en pb pd pm pn pw st adp pdr usr vdr)],
+        'hppolget'  => [qw(b f eh gl pw usr)],
+        'hppolset'  => [qw(b f eh fc pw usr)],
+        'hrefresh'  => [qw(b iv pl pr ps pv st nst debug nolock)],
+        'hrepedit'  => [qw(b eh fo pw rp all usr ismv isren ppath tpath rnpath newname oldname)],
+        'hrepmngr'  => [qw(b c r co cp cr eh er fc ld mv nc nc pw rm rp all cep coe del drn drp dup isv mvs ren rpw srn srp upd usr appc gext ndac nmvs rext rusr noext rport addext appext remext addsgrp addugrp addvgrp newname oldname remsgrp remugrp remvgrp)],
         'hri'       => [qw(b p de eh en ob ot pn pw st vp usr)],
         'hrmvpth'   => [qw(b p de eh en ob ot pn pw st vp usr)],
-        'hcrtpath'  => [qw(b p de eh en ob ot pw rp st usr cipn)],
-        'hrefresh'  => [qw(b iv pl pr ps pv st nst debug nolock)],
-        'hlv'       => [qw(b s ac cd eh en pn pw ss st vn vp usr)],
-        'hcbl'      => [qw(b eh en pw rp rw ss st add rdp rmr usr)],
-        'hcpj'      => [qw(b eh pw act cpj cug dac ina npj tem usr)],
-        'hpg'       => [qw(b bp eh en pg pw st app cpg dpg dpp usr)],
-        'hexecp'    => [qw(b m er ma pw prg syn usr args asyn rport)],
-        'husrmgr'   => [qw(b ad ae cf du eh nn ow pw cpw dlm swl usr)],
-        'hmvitm'    => [qw(b p de eh en np ob ot pn pw st uk ur vp usr)],
-        'hmvpth'    => [qw(b p de eh en np ob ot pn pw st uk ur vp usr)],
-        'hrnpth'    => [qw(b p de eh en nn ob ot pn pw st uk ur vp usr)],
-        'hsv'       => [qw(b p s eh en gl ib id io it iu iv pw st vp usr)],
         'hrnitm'    => [qw(b p de eh en nn ob on ot pn pw st uk ur vp usr)],
-        'hcropmrg'  => [qw(b eh mo p1 p2 pn pw en1 en2 plo st1 st2 usr vfs)],
-        'hlr'       => [qw(b c f cp eh er pw rm rp rpw usr rcep rusr rport)],
+        'hrnpth'    => [qw(b p de eh en nn ob ot pn pw st uk ur vp usr)],
+        'hrt'       => [qw(b f m eh er pw mpw usr musr rport)],
+        'hsigget'   => [qw(a t v gl purge)],
+        'hsigset'   => [qw(purge context)],
+        'hsmtp'     => [qw(d f m p s cc bcc)],
+        'hspp'      => [qw(b s eh en fp pn pw st tp usr)],
+        'hsql'      => [qw(b f s t eh eh gl nh pw usr)],
+        'hsv'       => [qw(b p s eh en gl ib id io it iu iv pw st vp usr)],
+        'hsync'     => [qw(b av bo br cp eh en er fv il iv pl pn ps pv pw rm ss st sy tb to vp ced iol rpw usr excl rusr excls purge rport complete)],
         'htakess'   => [qw(b p eh en pb pg pn po pw rs ss st ts ve vp abv usr)],
         'hucache'   => [qw(b eh en er pw ss st vp rpw usr rusr purge rport cacheagent)],
-        'hcmpview'  => [qw(b s eh pw en1 en2 st1 usr uv1 uv2 vn1 vn2 vp1 vp2 cidc ciic)],
-        'hfatt'     => [qw(b at cp eh er fn ft pw rm add fid get rem rpw usr comp rusr rport)],
+        'hudp'      => [qw(b ap eh en ip pn pw st usr)],
         'hup'       => [qw(b p af at cf eh en ft nt pr pw rf afo apg del des npn rfo rpg usr)],
-        'hrepedit'  => [qw(b eh fo pw rp all usr ismv isren ppath tpath rnpath newname oldname)],
-        'hci'       => [qw(b d p s bo cp de eh en er if nd ob op ot pn pw rm ro st tr uk ur vp dcp dvp rpw usr rusr rport)],
-        'hsync'     => [qw(b av bo br cp eh en er fv il iv pl pn ps pv pw rm ss st sy tb to vp ced iol rpw usr excl rusr excls purge rport complete)],
-        'hco'       => [qw(b p r s bo br cp cu eh en er nt op pf pn po pw rm ro ss st sy tb to tr up vn vp ced dcp dvp nvf nvs rpw usr rusr rport replace)],
-        'hrepmngr'  => [qw(b c r co cp cr eh er fc ld mv nc nc pw rm rp all cep coe del drn drp dup isv mvs ren rpw srn srp upd usr appc gext ndac nmvs rext rusr noext rport addext appext remext addsgrp addugrp addvgrp newname oldname remsgrp remugrp remvgrp)],
+        'husrmgr'   => [qw(b ad ae cf du eh nn ow pw cpw dlm swl usr)],
+        'husrunlk'  => [qw(b eh pw usr)],
     };
 
 #>>>
-    my @cmd_options =
-        sort { lc $a cmp lc $b }
+    my @cmd_options = sort { lc $a cmp lc $b }
         ( @{ $options->{common} }, @{ $options->{$cmd} } );
     return @cmd_options;
 } ## end sub _get_cmd_options
